==> docker-client-8.0.0-sources.jar: com/spotify/docker/client/messages/swarm/ContainerStatus.java <==
/*-
 * -\-\-
 * docker-client
 * --
 * Copyright (C) 2016 Spotify AB
 * --
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * -/-/-
 */

package com.spotify.docker.client.messages.swarm;

import static com.fasterxml.jackson.annotation.JsonAutoDetect.Visibility.ANY;
import static com.fasterxml.jackson.annotation.JsonAutoDetect.Visibility.NONE;

import com.fasterxml.jackson.annotation.JsonAutoDetect;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.google.auto.value.AutoValue;

import javax.annotation.Nullable;

@AutoValue
@JsonAutoDetect(fieldVisibility = ANY, getterVisibility = NONE, setterVisibility = NONE)
public abstract class ContainerStatus {

  @Nullable
  @JsonProperty("ContainerID")
  public abstract String containerId();

  @Nullable
  @JsonProperty("PID")
  public abstract Integer pid();

  @Nullable
  @JsonProperty("ExitCode")
  public abstract Integer exitCode();

  @JsonCreator
  static ContainerStatus create(
      @JsonProperty("ContainerID") final String containerId,
      @JsonProperty("PID") final Integer pid,
      @JsonProperty("ExitCode") final Integer exitCode) {
    return new AutoValue_ContainerStatus(containerId, pid, exitCode);
  }
}

==> docker-client-8.14.1-sources.jar: com/spotify/docker/client/messages/swarm/ContainerStatus.java <==
/*-
 * -\-\-
 * docker-client
 * --
 * Copyright (C) 2016 Spotify AB
 * --
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * -/-/-
 */

package com.spotify.docker.client.messages.swarm;

import static com.fasterxml.jackson.annotation.JsonAutoDetect.Visibility.ANY;
import static com.fasterxml.jackson.annotation.JsonAutoDetect.Visibility.NONE;

import com.fasterxml.jackson.annotation.JsonAutoDetect;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.google.auto.value.AutoValue;

import javax.annotation.Nullable;

@AutoValue
@JsonAutoDetect(fieldVisibility = ANY, getterVisibility = NONE, setterVisibility = NONE)
public abstract class ContainerStatus {

  @Nullable
  @JsonProperty("ContainerID")
  public abstract String containerId();

  @Nullable
  @JsonProperty("PID")
  public abstract Integer pid();

  @Nullable
  @JsonProperty("ExitCode")
  public abstract Long exitCode();

  @JsonCreator
  static ContainerStatus create(
      @JsonProperty("ContainerID") final String containerId,
      @JsonProperty("PID") final Integer pid,
      @JsonProperty("ExitCode") final Long exitCode) {
    return new AutoValue_ContainerStatus(containerId, pid, exitCode);
  }
}
